
## CATO-CLI - mutation.site.updateSiteBwLicense:
[Click here](https://api.catonetworks.com/documentation/#mutation-updateSiteBwLicense) for documentation on this operation.

### Usage for mutation.site.updateSiteBwLicense:

`catocli mutation site updateSiteBwLicense -h`

`catocli mutation site updateSiteBwLicense <json>`

`catocli mutation site updateSiteBwLicense "$(cat < updateSiteBwLicense.json)"`

`catocli mutation site updateSiteBwLicense '{"updateSiteBwLicenseInput": {"bw": {"bw": "Int"}, "licenseId": {"licenseId": "ID"}, "siteRefInput": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}}}'`

#### Operation Arguments for mutation.site.updateSiteBwLicense ####
`accountId` [ID] - (required) N/A 
`updateSiteBwLicenseInput` [UpdateSiteBwLicenseInput] - (required) N/A 
